# SyncSign Python SDK

This client library is designed to support the [SyncSign API](https://dev.sync-sign.com/webapi/) for SyncSign IoT system. You can read more about the API by accessing its official documentation.
